import os, time
from threading import Thread
from beartype import beartype
from beartype.typing import Union


class ArgoWorkflowsProgressReporter:
    def __init__(self) -> None:
        # Set the default variables
        self.current_progress = 0
        self.total_progress = 100
        self.save_interval = 2

    @beartype
    def set_current_progress(self, current_progress: Union[float, int]) -> None:
        self.current_progress = current_progress

    @beartype
    def set_total_progress(self, total_progress: Union[float, int]) -> None:
        self.total_progress = total_progress

    @beartype
    def set_progress_complete(self, default_progress: int = 100) -> None:

        if self.current_progress > self.total_progress:
            self.total_progress = self.current_progress
            return None

        if self.total_progress > self.current_progress:
            self.current_progress = self.total_progress
            return None

        if self.total_progress == self.current_progress:
            if self.total_progress == 0 or self.current_progress == 0:
                self.total_progress = default_progress
                self.current_progress = default_progress

        return None

    @beartype
    def set_save_interval(self, save_interval: Union[float, int]) -> None:
        self.save_interval = save_interval

    @beartype
    def get_progress_file_path(self) -> str:
        return os.environ.get("ARGO_PROGRESS_FILE", "/tmp/progress.txt")

    @beartype
    def get_progress_percent(self) -> Union[float, int]:
        try:
            return self.current_progress / self.total_progress
        except:
            return 0

    @beartype
    def save_file(self) -> None:
        while True:
            with open(self.get_progress_file_path(), "w") as f:
                f.write("%s/%s" % (self.current_progress, self.total_progress))
                f.close
            time.sleep(self.save_interval)

    @beartype
    def start_reporting(self) -> None:

        # Make the storage directory
        os.makedirs(os.path.dirname(self.get_progress_file_path()), exist_ok=True)

        # Start the file save thread
        t = Thread(target=self.save_file)
        t.daemon = True
        t.start()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['awpr']

package_data = \
{'': ['*']}

install_requires = \
['beartype>=0.10.4,<0.11.0', 'loguru>=0.6.0,<0.7.0']

setup_kwargs = {
    'name': 'awpr',
    'version': '0.0.37',
    'description': 'Library that helps an application report progress to Argo Workflows.',
    'long_description': '# awpr\nLibrary that helps an application report progress to Argo Workflows.\n\n\n## Installation \n```shell\npip install awpr\n```\n\n## Usage\nSet the environment variable and run your application:\n`ARGO_PROGRESS_FILE=/tmp/progress.txt`\n\n```shell\nfrom awpr.awpr import ArgoWorkflowsProgressReporter\n\nawpr = ArgoWorkflowsProgressReporter()\nawpr.set_total_progress(100)\nawpr.start_reporting()\n\nawpr.set_current_progress(20)\nawpr.set_current_progress(30)\nawpr.get_progress_percent()\n\nawpr.set_progress_complete()\nawpr.get_progress_percent()\n```',
    'author': 'Michael Mohamed',
    'author_email': 'michael@foundationstack.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/fsai-dev/fsai-cli-tools',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
